@@ -477,6 +477,9 @@ class BWQueries(BWResource, bwdata.BWData):
         filled["type"] = data.get("query_type", "monitor")
         filled["contentSources"] = data.get("contentSources", default_content_sources)
         filled["samplePercentage"] = data.get("samplePercentage", 100)
+        # set userRequestedSampling to True if the sample rate < 100, otherwise field is not needed
+        if filled["samplePercentage"] < 100:
+            filled["userRequestedSampling"] = True
         filled["description"] = data.get("description", "")
         # languages field defaults to an empty list to create a language agnostic query
         filled["languages"] = data.get("languages", list())
@@ -1510,10 +1513,10 @@ class BWRules(BWResource):
         filled["ruleAction"] = data["ruleAction"]
         filled["projectId"] = self.project.project_id
 
-        # validating the query search - comment this out to skip validation
+        # validating the query search
         if "search" in filled["filter"]:
             self.project.validate_rule_search(
-                query=filled["filter"]["search"], language="en"
+                booleanQuery=filled["filter"]["search"], language="en"
             )
 
         if "scope" in data:
